@@ -1,4 +1,4 @@
-/* $Id: first.c,v 1.45 2003/10/20 15:19:36 hadess Exp $ */
+/* $Id: first.c,v 1.48 2005/12/12 09:37:58 jamesh Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,7 +21,13 @@
    Boston, MA 02111-1307, USA.
 */
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #include <locale.h>
+#include <libintl.h>
+#include <stdio.h>
 
 #include <glibtop.h>
 #include <glibtop/open.h>
@@ -53,7 +59,7 @@ main (int argc, char *argv [])
 	setlocale (LC_ALL, "");
 	bindtextdomain (GETTEXT_PACKAGE, GTOPLOCALEDIR);
 	textdomain (GETTEXT_PACKAGE);
-	
+
 	glibtop_init_r (&glibtop_global_server, 0, GLIBTOP_INIT_NO_OPEN);
 
 	glibtop_get_parameter (GLIBTOP_PARAM_METHOD, &method, sizeof (method));
@@ -133,7 +139,7 @@ main (int argc, char *argv [])
 
 	for (c = 0; c < PROFILE_COUNT; c++)
 		glibtop_get_shm_limits (&data.shm_limits);
-	
+
 	printf ("Shm Limits   (0x%08lx): %lu, %lu, %lu, %lu, %lu\n",
 		(unsigned long) data.shm_limits.flags,
 		(unsigned long) data.shm_limits.shmmax,
@@ -157,7 +163,7 @@ main (int argc, char *argv [])
 
 	for (c = 0; c < PROFILE_COUNT; c++)
 		glibtop_get_sem_limits (&data.sem_limits);
-	
+
 	printf ("Sem Limits   (0x%08lx): "
 		"%lu, %lu, %lu, %lu, %lu, %lu, %lu, %lu, %lu, %lu\n",
 		(unsigned long) data.sem_limits.flags,
@@ -215,7 +221,7 @@ main (int argc, char *argv [])
 		(unsigned long) sysdeps.ppp);
 
 	printf ("\n");
-	
+
 	ptr = glibtop_get_proclist (&data.proclist, 0, 0);
 
 	printf ("Proclist     (0x%08lx): %lu, %lu, %lu\n",
@@ -306,7 +312,7 @@ main (int argc, char *argv [])
 
 	for (c = 0; c < PROFILE_COUNT; c++)
 		glibtop_get_proc_signal (&data.proc_signal, pid);
-	
+
 	printf ("Proc_Signal  PID  %5d (0x%08lx): "
 		"%lu %lu %lu %lu\n", (int) pid,
 		(unsigned long) data.proc_signal.flags,
