@@ -1,4 +1,4 @@
-/* $Id: proclist.h,v 1.29 2004/07/18 20:33:55 bdejean Exp $ */
+/* $Id: proclist.h,v 1.31 2005/06/07 09:54:43 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -62,7 +62,8 @@ struct _glibtop_proclist
 		size;			/* GLIBTOP_PROCLIST_SIZE	*/
 };
 
-#define glibtop_get_proclist(proclist,which,arg) glibtop_get_proclist_l(glibtop_global_server, proclist, which, arg)
+unsigned *
+glibtop_get_proclist(glibtop_proclist *buf, gint64 which, gint64 arg);
 
 #if GLIBTOP_SUID_PROCLIST
 #define glibtop_get_proclist_r		glibtop_get_proclist_p
@@ -88,16 +89,6 @@ glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
 			gint64 which, gint64 arg);
 #endif
 
-#ifdef GLIBTOP_NAMES
-
-/* You need to link with -lgtop_names to get this stuff here. */
-
-extern const char *glibtop_names_proclist [];
-extern const unsigned glibtop_types_proclist [];
-extern const char *glibtop_labels_proclist [];
-extern const char *glibtop_descriptions_proclist [];
-
-#endif
 
 G_END_DECLS
 
